[Python-checkins] cpython (3.2): Update __all__ and docstring.

ezio.melotti python-checkins at python.org
Sat May 14 13:57:27 CEST 2011


http://hg.python.org/cpython/rev/b2bcddfb8b18
changeset:   70097:b2bcddfb8b18
branch:      3.2
parent:      70094:bc251b65de1d
user:        Ezio Melotti <ezio.melotti at gmail.com>
date:        Sat May 14 14:51:18 2011 +0300
summary:
  Update __all__ and docstring.

files:
  Lib/test/support.py |  4 +++-
  1 files changed, 3 insertions(+), 1 deletions(-)


diff --git a/Lib/test/support.py b/Lib/test/support.py
--- a/Lib/test/support.py
+++ b/Lib/test/support.py
@@ -37,6 +37,7 @@
     "findfile", "sortdict", "check_syntax_error", "open_urlresource",
     "check_warnings", "CleanImport", "EnvironmentVarGuard",
     "TransientResource", "captured_output", "captured_stdout",
+    "captured_stdin", "captured_stderr",
     "time_out", "socket_peer_reset", "ioerror_peer_reset",
     "run_with_locale", 'temp_umask', "transient_internet",
     "set_memlimit", "bigmemtest", "bigaddrspacetest", "BasicTestRunner",
@@ -891,7 +892,7 @@
 
 @contextlib.contextmanager
 def captured_output(stream_name):
     """Return a context manager used by captured_stdout and captured_stdin
     that temporarily replaces the sys stream *stream_name* with a StringIO."""
     import io
     orig_stdout = getattr(sys, stream_name)
@@ -916,6 +917,7 @@
 def captured_stdin():
     return captured_output("stdin")
 
+
 def gc_collect():
     """Force as many objects as possible to be collected.
 
@@ -891,7 +892,7 @@
 @contextlib.contextmanager
 def captured_output(stream_name):
-    """Return a context manager used by captured_stdout and captured_stdin
+    """Return a context manager used by captured_stdout/stdin/stderr
     that temporarily replaces the sys stream *stream_name* with a StringIO."""
     import io

-- 
Repository URL: http://hg.python.org/cpython


More information about the Python-checkins mailing list